@@ -1,12 +1,12 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /cvsroot/pgpool/pgpool-II/pool_hba.c,v 1.1 2007/05/23 01:59:28 yamaguti Exp $
+ * $Header: /cvsroot/pgpool/pgpool-II/pool_hba.c,v 1.6 2009/08/22 04:04:21 t-ishii Exp $
  *
- * pgpool: a language independent connection pool server for PostgreSQL 
+ * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Portions Copyright (c) 2003-2007	PgPool Global Development Group
+ * Portions Copyright (c) 2003-2008	PgPool Global Development Group
  * Portions Copyright (c) 1996-2005, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California                                          *
  * Permission to use, copy, modify, and distribute this software and
@@ -33,6 +33,7 @@
 #include "pool.h"
 #include "pool_path.h"
 #include "pool_ip.h"
+#include "parser/pool_memory.h"
 #include "parser/pg_list.h"
 
 #define MULTI_VALUE_SEP "\001" /* delimiter for multi-valued column strings */
@@ -97,11 +98,11 @@ static POOL_CONNECTION *pam_frontend_kludge; /* Workaround for passing
 void load_hba(char *hbapath)
 {
 	FILE *file;
-	
+
 	POOL_MEMORY_POOL *old_context;
 	if (hba_memory_context == NULL)
 	{
-		hba_memory_context = pool_memory_create();
+		hba_memory_context = pool_memory_create(PARSER_BLOCK_SIZE);
 		if (hba_memory_context == NULL)
 		{
 			pool_error("load_hba: pool_memory_create() failed");
@@ -154,7 +155,7 @@ void ClientAuthentication(POOL_CONNECTION *frontend)
 		 * use exit(2) since this is not so fatal. other entries in
 		 * pool_hba.conf may be valid, so treat it as reject.
 		 */
-		exit(2);
+		child_exit(2);
 	}
 
 	switch (frontend->auth_method)
@@ -184,9 +185,9 @@ void ClientAuthentication(POOL_CONNECTION *frontend)
 			if ((errmessage = (char *)malloc(messagelen+1)) == NULL)
 			{
 				pool_error("ClientAuthentication: malloc failed: %s", strerror(errno));
-				exit(1);
+				child_exit(1);
 			}
-			
+
 #ifdef USE_SSL
 			snprintf(errmessage, messagelen+7, /* +7 is for "SSL off" */
 					 "no pool_hba.conf entry for host \"%s\", user \"%s\", database \"%s\", %s",
@@ -200,7 +201,7 @@ void ClientAuthentication(POOL_CONNECTION *frontend)
 			pool_error(errmessage);
 			pool_send_error_message(frontend, frontend->protoVersion, "XX000", errmessage,
 									"", "", __FILE__, __LINE__);
-		
+
 			free(errmessage);
 			break;
 		}
@@ -302,7 +303,7 @@ static char *recv_password_packet(POOL_CONNECTION *frontend)
 
 		if (pool_read(frontend, &kind, 1) < 0)
 			return NULL;
-		
+
 		if (kind != 'p')
 		{
 			pool_error("expected password response, got message type %c",
@@ -311,7 +312,7 @@ static char *recv_password_packet(POOL_CONNECTION *frontend)
 		}
 	}
 	/* pre-3.0 protocol does not send a message type */
-	
+
 	if (pool_read(frontend, &rsize, sizeof(int)) < 0)
 		return NULL;
 
@@ -352,7 +353,7 @@ static void auth_failed(POOL_CONNECTION *frontend)
 	if ((errmessage = (char *)malloc(messagelen+1)) == NULL)
 	{
 		pool_error("auth_failed: malloc failed: %s", strerror(errno));
-		exit(1);
+		child_exit(1);
 	}
 
 	switch (frontend->auth_method)
@@ -416,7 +417,7 @@ static void auth_failed(POOL_CONNECTION *frontend)
 	 * don't need to free(errmessage). I will just kill myself.
 	 */
 	close_all_backend_connections();
-	exit(2);
+	child_exit(2);
 }
 
 
@@ -697,11 +698,11 @@ static void parse_hba(List *line, int line_num, POOL_CONNECTION *frontend,
 				return;
 			}
 		}
-		
+
 		/* Ignore line if client port is not in the matching addr range. */
 		if (!rangeSockAddr(&frontend->raddr.addr, &addr, &mask))
 			return;
-		
+
 		/* Read the rest of the line. */
 		line_item = lnext(line_item);
 		if (!line_item)
@@ -713,7 +714,7 @@ static void parse_hba(List *line, int line_num, POOL_CONNECTION *frontend,
 	}
 	else
 		goto hba_syntax;
-	
+
 	/* Does the entry match database and user? */
 	/*
 	 * duplicate db and username since strtok() in check_db() and check_user()
@@ -1250,17 +1251,17 @@ static void free_lines(List **lines, List **line_nums)
 		{
 			List *ln = lfirst(line);
 			ListCell *token;
-			
+
 			foreach(token, ln)
 				free(lfirst(token));
 
 			list_free(ln);
 		}
-		
+
 		list_free(*lines);
 		*lines = NIL;
 	}
-	
+
 	if (*line_nums)
 	{
 		list_free(*line_nums);
